@@ -1,9 +1,8 @@
 import time
 
-import requests
 from tqdm import tqdm
 
-from .common import npu_print, NEURO_AI_STR
+from .common import npu_print, NEURO_AI_STR, get_response, get
 from .web.urls import TASK_STATUS_URL
 from threading import Thread
 
@@ -15,6 +14,7 @@ STOPPED = "STOPPED"
 TASK_DONE_LIST = (FAILURE, COMPLETE, STOPPED)
 
 bar_suffix = NEURO_AI_STR + " {desc}: {percentage:.1f}%|{bar}| remaining: {remaining} || elapsed: {elapsed} "
+dash_str = "Started {0}. View status at https://dashboard.neuro-ai.co.uk/task?id={1}"
 one_hundred_percent = 100
 
 
@@ -22,6 +22,7 @@ class Task:
 
     def __init__(self, task_id, callback=None, show=True):
         self.task_id = task_id
+        self.url = TASK_STATUS_URL + self.task_id
         self.task_result = ""
         self.task_type = ""
         self.progress = 0
@@ -30,16 +31,15 @@ class Task:
         self.cache = None
         self._logs = {}
         self.prints = []
+        self.params = {"include_result": False}
         if self.callback:
             t = Thread(target=self.callback_thread)
             t.start()
         if show:
             self.update()
-            npu_print("Started {0}. View status at https://dashboard.neuro-ai.co.uk/task?id={1}".format(self.task_type.lower(), task_id))
-
+            npu_print(dash_str.format(self.task_type.lower(), task_id))
+            
     def wait(self):
-        # if self.finished():
-        #     return
         with tqdm(desc=self.task_type, total=one_hundred_percent,
                   bar_format=bar_suffix) as bar:
             while not self.finished():
@@ -66,10 +66,9 @@ class Task:
         return self.task_result
 
     def update(self, include_result=False):
-        from .common import getResponse
-        params = {"include_result": include_result}
-        response = requests.get(TASK_STATUS_URL + self.task_id, params=params)
-        response = getResponse(response)
+        self.params["include_result"] = include_result
+        response = get(self.url, params=self.params)
+        response = get_response(response)
         self.task_state = response["state"]
         self.task_type = response["taskType"]
         self.progress = response["progress"]
