@@ -1,13 +1,11 @@
 import glob
 import hashlib
 import os
-import sys
 import tarfile
 from io import BytesIO
 
 import numpy as np
 
-
 pytorch_str = "pytorch"
 mxnet_str = "mxnet"
 TF_str = "TF"
@@ -33,18 +31,6 @@ def save_model(model, library: str):
             from torch import save
             import dill
             model_path += ".pt"
-            try:
-                # from pytorch_lightning import LightningModule
-                # if isinstance(model, LightningModule):
-                    try:
-                        import cloudpickle
-                        dill = cloudpickle
-                    except ModuleNotFoundError as _:
-                        from ..common import npu_print
-                        npu_print("To use pytorch lightning, please install cloudpickle.", level="ERROR")
-                        sys.exit(1)
-            except ModuleNotFoundError as _:
-                pass
             save(model, model_path, pickle_module=dill)
         elif library == "keras":
             model_path += ".h5"
