@@ -1,7 +1,7 @@
 from . import core, optim, loss as _loss, metrics as _metrics
 
 
-def api(token="", project="Default", verbosity=1):
+def api(token="", project="Default", verbosity=1, deployed=False):
     """Use this function to get access to the API, providing your token. All subsequents API calls will use this token.
 
         :param token: Token from dashboard. Set environment variable NPU_API_TOKEN to bypass
@@ -10,8 +10,10 @@ def api(token="", project="Default", verbosity=1):
         :type project: str
         :param verbosity: Print level for client. Useful for debugging.
         :type verbosity: int
+        :param deployed: In deployment mode or not
+        :type deployed: bool
     """
-    core.api(token, project, verbosity)
+    core.api(token, project, verbosity, deployed)
 
 
 def compile(model, input_shape=None, library="", model_label="", asynchronous=False):
@@ -52,7 +54,7 @@ def upload_data(data, name=""):
     return core.upload_data(data, name)
 
 
-def predict(model, data, asynchronous=False, callback=None, **kwargs):
+def predict(model, data, input_kwargs=None, asynchronous=False, callback=None, scripts=None, **kwargs):
     """Perform a predict using a model. Default behaviour is synchronous.
 
         :param model: Model used to predict
@@ -64,10 +66,14 @@ def predict(model, data, asynchronous=False, callback=None, **kwargs):
         :param callback: runs a callback function on results (asynchronous)
         :type callback: function
     """
-    return core.predict(model, data, asynchronous, callback, **kwargs)
+    if scripts is None:
+        scripts = []
+    if input_kwargs is None:
+        input_kwargs = {}
+    return core.predict(model, data, input_kwargs, asynchronous, callback, scripts, **kwargs)
 
 
-def train(model, train_data, val_data="", batch_size=32, epochs=1, optim=optim.SGD(), loss=_loss.SparseCrossEntropyLoss,
+def train(model, train_data, val_data="", train_kwargs=None, val_kwargs=None, batch_size=32, epochs=1, optim=optim.SGD(), loss=_loss.SparseCrossEntropyLoss,
           metrics=None, trained_model_name="", asynchronous=False, callback=None, **kwargs):
     """Perform a train using a model. Default behaviour is synchronous.
 
@@ -97,13 +103,17 @@ def train(model, train_data, val_data="", batch_size=32, epochs=1, optim=optim.S
         :type callback: function
 
     """
+    if train_kwargs is None:
+        train_kwargs = {}
+    if val_kwargs is None:
+        val_kwargs = {}
     assert type(batch_size) is int
     assert type(epochs) is int
     assert batch_size > 0
     assert epochs > 0
     if metrics is None:
         metrics = [_metrics.Accuracy]
-    return core.train(model, train_data, val_data, batch_size, epochs, optim, loss, metrics, trained_model_name,
+    return core.train(model, train_data, val_data, train_kwargs, val_kwargs, batch_size, epochs, optim, loss, metrics, trained_model_name,
                       asynchronous, callback, **kwargs)
 
 
